@@ -27,7 +27,8 @@ func (p *Python) Init(props properties.Properties, env environment.Environment)
 	p.language = language{
 		env:         env,
 		props:       props,
-		extensions:  []string{"*.py", "*.ipynb", "pyproject.toml", "venv.bak", "venv", ".venv"},
+		extensions:  []string{"*.py", "*.ipynb", "pyproject.toml", "venv.bak"},
+		folders:     []string{".venv", "venv", "virtualenv", "env", "venv-win", "pyenv-win"},
 		loadContext: p.loadContext,
 		inContext:   p.inContext,
 		commands: []*cmd{
